@@ -150,7 +150,7 @@ class Trafaret(object):
         Appends new converter to list.
         """
         if hasattr(self, 'converters'):
-            self.checkers.append(converter)
+            self.converters.append(converter)
         else:
             self.converters = [converter]
         return self
@@ -708,7 +708,9 @@ class Key(object):
             raise StopIteration
         if not self.optional:
             yield self.name, DataError(error='is required')
-        raise StopIteration
+
+    def keys_names(self):
+        yield self.name
 
     def set_trafaret(self, trafaret):
         self.trafaret = trafaret
@@ -804,6 +806,11 @@ class Dict(Trafaret):
             raise DataError(error=errors)
         return collect
 
+    def keys_names(self):
+        for key in self.keys:
+            for k in key.keys_names():
+                yield k
+
     def __repr__(self):
         r = "<Dict("
         options = []
